import { getProfileRoute } from '../../routes'

import styles from './styles.module.scss'
import { AvatarIconButton } from '../UserAvatarIconButton'
import { Link } from 'react-router-dom'

interface UserAvatarProps {
  name?: string
  pubkey: string
  image?: string
}

/**
 *  This component will be used for the displaying username and profile picture.
 *  Clicking will navigate to the user's profile.
 */
export const UserAvatar = ({ pubkey, name, image }: UserAvatarProps) => {
  return (
    <Link
      to={getProfileRoute(pubkey)}
      className={styles.container}
      tabIndex={-1}
    >
      <AvatarIconButton
        src={image}
        hexKey={pubkey}
        aria-label={`account of user ${name || pubkey}`}
        color="inherit"
        sx={{
          padding: 0
        }}
      />
      {name ? <span className={styles.username}>{name}</span> : null}
    </Link>
  )
}
